@@ -426,7 +426,6 @@ class PhaseSpace(object):
         imax = len(self.spaces)-1
         i = 0
         for space in self.spaces:
-            print 'space hull %s/%s : %s' % (i, imax, space)
             i += 1
             space = PhaseSpace('-'.join(space), pdata=self._data, load=None)
             space.get_qhull()
@@ -458,7 +457,6 @@ class PhaseSpace(object):
         imax = len(self.dual_spaces)-1
         i = 0
         for space in self.dual_spaces:
-            print 'dual space hull %s/%s : %s' % (i, imax, space)
             i += 1
             space = PhaseSpace('-'.join(space), pdata=self._data, load=None)
             space.get_qhull()
@@ -526,7 +524,6 @@ class PhaseSpace(object):
                 mus=mus, phases=in_phases)
 
     def _gclp(self, composition={}, mus={}, phases=[]):
-        print phases
         prob = LpProblem('GibbsEnergyMin', LpMinimize)
         phase_vars = LpVariable.dicts('lib', phases, 0.0)
         prob += lpSum([ (phase.energy -
@@ -912,7 +909,7 @@ class PhaseSpace(object):
         '''
         if isinstance(var, basestring):
             var = parse_comp(var)
-        vname = format_comp(reduce_comp(v))
+        vname = format_comp(reduce_comp(var))
         vphase = self.phase_dict[vname]
         for facet in self.hull:
             reacts, prods, delta_var = self.get_reaction(var, facet=facet)
