@@ -13,6 +13,7 @@ from qmpy.data.meta_data import *
 from qmpy.analysis.symmetry import Spacegroup
 from qmpy.analysis.symmetry import *
 from qmpy.analysis.pdf import get_pdf_uri
+from transforms import *
 
 class StructureError(Exception):
     '''Structure related problem'''
@@ -444,6 +445,7 @@ class Structure(models.Model, object):
         coords = []
         for atom in self.atoms:
             if atom.direct:
+                #coords.append(atom.coord*s.cell)
                 coords.append(np.dot(atom.coord, self.cell))
             else:
                 coords.append(atom.coord)
@@ -498,17 +500,10 @@ class Structure(models.Model, object):
             atom1 = self.atoms[atom1]
         if isinstance(atom2, int):
             atom2 = self.atoms[atom2]
-        if atom1.direct:
-            v1 = np.dot(atom1.coord, self.cell)
-        else:
-            v1 = atom1.coord
-        if atom2.direct:
-            v2 = np.dot(atom2.coord, self.cell)
-        else:
-            v2 = atom2.coord
-        vec = v1 - v2
-        Dr = solve(self.cell.T, vec)
-        D = np.dot(Dr - np.round(Dr), self.cell)
+
+        vec = atom1.coord - atom2.coord
+        #Dr = solve(self.cell.T, vec)
+        D = np.dot(vec - np.round(vec), self.cell)
         return norm(D)
 
     def copy(self):
@@ -544,6 +539,7 @@ class Structure(models.Model, object):
 
     def make_primitive(self):
         '''Uses spglib to convert to the primitive cell.'''
+        self.make_conventional()
         find_primitive(self)
 
     def get_sites(self, tol=1e-3):
@@ -574,6 +570,9 @@ class Structure(models.Model, object):
         resort = np.argsort(eq)
         self._atoms = list(np.array(self._atoms)[resort])
 
+    def substitute(self, replace):
+        return substitute(self, replace)
+
 class Prototype(models.Model):
     name = models.CharField(max_length=63, primary_key=True)
     structure = models.ForeignKey(Structure, related_name='+', 
