@@ -1,8 +1,9 @@
-from my_math import *
-from my_strings import *
-#import my_strings
-from miedema import get_energy
-from cif_to_poscar import *
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+
+from math import *
+from strings import *
+from daemon import Daemon
 
 def assign_type(string):
     res = string
@@ -38,3 +39,18 @@ def combinations_with_replacement(iterable, r):
             return
         indices[i:] = [indices[i] + 1] * (r - i)
         yield tuple(pool[i] for i in indices)
+
+def atom_sort(atoms):
+    atoms = np.array(atoms)
+    x = [ a.x for a in atoms ]
+    y = [ a.y for a in atoms ]
+    z = [ a.z for a in atoms ]
+    ox = [ a.ox for a in atoms ]
+    elt = [ a.element_id for a in atoms ]
+    comps = []
+    for l in [x, y, z, ox, elt ]:
+        if any(l):
+            comps.append(l)
+    if len(comps) == 0:
+        return atoms
+    return atoms[np.lexsort(comps)].tolist()
